@@ -13,8 +13,10 @@ use Nile::Base;
 sub home  : GET Action {
 	
 	my ($self) = @_;
+	
+	my $me = $self->me;
 
-	my $view = $self->me->view("home");
+	my $view = $me->view("home");
 	
 	$view->var(
 			fname			=>	'Ahmed',
@@ -24,9 +26,27 @@ sub home  : GET Action {
 			singleline		=>	'Single line variable <b>Good</b>',
 			multiline		=>	'Multi line variable <b>Nice</b>',
 		);
+	
+	#$view->block;
+	
+	#my $var = $view->block();
+	#say "keys: ". keys %$var;
+	#$view->parse;
+	#say "blocks dump: " . $me->dump($view->block());
+
+	#say "block: " . $me->dump($view->block("first/second/third/fourth/fifth"));
+	#$view->block("first/second/third/fourth/fifth", "Block Modified ");
+	#say "block: " . $me->dump($view->block("first/second/third/fourth/fifth"));
+
+	$view->block("first", "1st Block New Content ");
+	$view->block("six", "6th Block New Content ");
+
+	#say "dump: " . $me->dump($view->block->{first}->{second}->{third}->{fourth}->{fifth});
+	
+	$view->show;
+	#$view->process;
+	#$view->render;
 
-	$view->process;
-	$view->render;
 }
 #=========================================================#
 
